Struct WpDrmLeaseRequestV1
pub struct WpDrmLeaseRequestV1 { /* private fields */ }wayland and Linux only.Expand description
DRM lease request
A client that wishes to lease DRM resources will attach the list of connectors advertised with wp_drm_lease_device_v1.connector that they wish to lease, then use wp_drm_lease_request_v1.submit to submit the request.
This interface has no events.
Implementations
impl WpDrmLeaseRequestV1
impl WpDrmLeaseRequestV1
pub fn request_connector(&self, connector: &WpDrmLeaseConnectorV1)
pub fn request_connector(&self, connector: &WpDrmLeaseConnectorV1)
request a connector for this lease
Indicates that the client would like to lease the given connector. This is only used as a suggestion, the compositor may choose to include any resources in the lease it issues, or change the set of leased resources at any time. Compositors are however encouraged to include the requested connector and other resources necessary to drive the connected output in the lease.
Requesting a connector that was created from a different lease device than this lease request raises the wrong_device error. Requesting a connector twice will raise the duplicate_connector error.
pub fn submit<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> WpDrmLeaseV1
pub fn submit<U, D>(&self, qh: &QueueHandle<D>, udata: U) -> WpDrmLeaseV1
submit the lease request
Submits the lease request and creates a new wp_drm_lease_v1 object. After calling submit the compositor will immediately destroy this object, issuing any more requests will cause a wl_display error. The compositor doesn’t make any guarantees about the events of the lease object, clients cannot expect an immediate response. Not requesting any connectors before submitting the lease request will raise the empty_lease error.